==> ddq_ui-0.1.4.tar.gz: ddq_ui-0.1.4/setup.py <==
from setuptools import setup, find_packages

setup(
    name="ddq_ui",
    version="0.1.4",
    packages=find_packages(),  # 自动发现所有包
    install_requires=[
    ],
    tests_require=[
        'pytest',
        'pytest-cov',
    ],
    test_suite='tests',
    python_requires='>=3.6',
    description="DDQ UI Framework - 一个灵活的 UI 框架，支持多种后端实现",
    long_description=open('README.md', encoding='utf-8').read(),
    long_description_content_type='text/markdown',
    author="DDQ",
    author_email="your.email@example.com",  # 请替换为您的邮箱
    url="https://github.com/yourusername/ddq_ui",  # 请替换为您的代码仓库地址
    classifiers=[
        "Development Status :: 3 - Alpha",
        "Intended Audience :: Developers",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Topic :: Software Development :: Libraries :: Python Modules",
        "Topic :: Software Development :: User Interfaces",
    ],
    keywords='ui, tkinter, framework, widgets',
    project_urls={
        'Documentation': 'https://github.com/yourusername/ddq_ui#readme',
        'Source': 'https://github.com/yourusername/ddq_ui',
        'Tracker': 'https://github.com/yourusername/ddq_ui/issues',
    },
)

==> ddq_ui-0.1.5.tar.gz: ddq_ui-0.1.5/setup.py <==
from setuptools import setup, find_packages

setup(
    name="ddq_ui",
    version="0.1.5",
    packages=find_packages(),  # 自动发现所有包
    install_requires=[
        # tkinter 是 Python 标准库，不需要在这里指定
    ],
    tests_require=[
        'pytest',
        'pytest-cov',
    ],
    test_suite='tests',
    python_requires='>=3.6',
    description="DDQ UI Framework - 一个灵活的 UI 框架，支持多种后端实现",
    long_description=open('README.md', encoding='utf-8').read(),
    long_description_content_type='text/markdown',
    author="DDQ",
    author_email="ddq@example.com",  # 请替换为您的实际邮箱
    url="https://github.com/ddq/ddq_ui",  # 请替换为您的实际仓库地址
    classifiers=[
        "Development Status :: 3 - Alpha",
        "Intended Audience :: Developers",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Topic :: Software Development :: Libraries :: Python Modules",
        "Topic :: Software Development :: User Interfaces",
    ],
    keywords='ui, tkinter, framework, widgets',
    project_urls={
        'Documentation': 'https://github.com/ddq/ddq_ui#readme',
        'Source': 'https://github.com/ddq/ddq_ui',
        'Tracker': 'https://github.com/ddq/ddq_ui/issues',
    },
)
